[libpng16] Imported from libpng-1.6.0beta08.tar
diff --git a/LICENSE b/LICENSE
index 37d986b..3faf51c 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, January 28, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, February 1, 2012, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 28, 2012
+February 1, 2012
diff --git a/README b/README
index 05ab1cb..55ae2bd 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.0beta08 - January 28, 2012 (shared library 16.0)
+README for libpng version 1.6.0beta08 - February 1, 2012 (shared library 16.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index 1acc964..abb9679 100644
--- a/configure.ac
+++ b/configure.ac
@@ -27,6 +27,8 @@
 # dist-xz requires automake 1.11 or later
 # 1.11.1 fixes a security issue in 1.11
 AM_INIT_AUTOMAKE([1.11.1 foreign dist-xz dist-bzip2 color-tests silent-rules])
+# was:
+# AM_INIT_AUTOMAKE
 AM_MAINTAINER_MODE
 
 dnl configure.ac and Makefile.am expect automake 1.11.2 or a compatible later
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 311fab4..5072f1d 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.0beta08 - January 28, 2012
+ libpng version 1.6.0beta08 - February 1, 2012
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.0beta08 - January 28, 2012
+ libpng versions 0.97, January 1998, through 1.6.0beta08 - February 1, 2012
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -4284,6 +4284,17 @@
 having level = 0 will be printed.  There aren't any such statements in
 this version of libpng, but if you insert some they will be printed.
 
+Prepending a prefix to exported symbols
+
+Starting with libpng-1.6.0, you can configure libpng (when using the
+"configure" script) to prefix all exported symbols by means of the
+configuration option "--with-libpng-prefix=FOO_", where FOO_ can be any
+string beginning with a letter and containing only uppercase
+and lowercase letters, digits, and the underscore (i.e., a C language
+identifier).  This creates a set of macros in pnglibconf.h, so this is
+transparent to applications; their function calls get transformed by
+the macros to use the modified names.
+
 VII.  MNG support
 
 The MNG specification (available at http://www.libpng.org/pub/mng) allows
@@ -4863,6 +4874,9 @@
 A "simplified API" has been added (see documentation in png.h and a simple
 example in contrib/examples/pngtopng.c)
 
+Starting with libpng-1.6.0, you can configure libpng to prefix all exported
+symbols.
+
 We no longer include string.h in png.h.  The include statement has been moved
 to pngpriv.h, where it is not accessible by applications.  Applications that
 need access to information in string.h must add an '#include "string.h"'
@@ -5029,7 +5043,7 @@
 
 XVI. Y2K Compliance in libpng
 
-January 28, 2012
+February 1, 2012
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index cfb4768..b793823 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "January 28, 2012"
+.TH LIBPNG 3 "February 1, 2012"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.6.0beta08
 .SH SYNOPSIS
@@ -1003,7 +1003,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.0beta08 - January 28, 2012
+ libpng version 1.6.0beta08 - February 1, 2012
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -1014,7 +1014,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.0beta08 - January 28, 2012
+ libpng versions 0.97, January 1998, through 1.6.0beta08 - February 1, 2012
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -5288,6 +5288,17 @@
 having level = 0 will be printed.  There aren't any such statements in
 this version of libpng, but if you insert some they will be printed.
 
+.SS Prepending a prefix to exported symbols
+
+Starting with libpng-1.6.0, you can configure libpng (when using the
+"configure" script) to prefix all exported symbols by means of the
+configuration option "--with-libpng-prefix=FOO_", where FOO_ can be any
+string beginning with a letter and containing only uppercase
+and lowercase letters, digits, and the underscore (i.e., a C language
+identifier).  This creates a set of macros in pnglibconf.h, so this is
+transparent to applications; their function calls get transformed by
+the macros to use the modified names.
+
 .SH VII.  MNG support
 
 The MNG specification (available at http://www.libpng.org/pub/mng) allows
@@ -5867,6 +5878,9 @@
 A "simplified API" has been added (see documentation in png.h and a simple
 example in contrib/examples/pngtopng.c)
 
+Starting with libpng-1.6.0, you can configure libpng to prefix all exported
+symbols.
+
 We no longer include string.h in png.h.  The include statement has been moved
 to pngpriv.h, where it is not accessible by applications.  Applications that
 need access to information in string.h must add an '#include "string.h"'
@@ -6033,7 +6047,7 @@
 
 .SH XVI. Y2K Compliance in libpng
 
-January 28, 2012
+February 1, 2012
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -6301,7 +6315,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.6.0beta08 - January 28, 2012:
+Libpng version 1.6.0beta08 - February 1, 2012:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -6324,7 +6338,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, January 28, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, February 1, 2012, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -6423,7 +6437,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 28, 2012
+February 1, 2012
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 5bc375c..804f555 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 28, 2012"
+.TH LIBPNGPF 3 "February 1, 2012"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.6.0beta08
 (private functions)
diff --git a/png.5 b/png.5
index 07bb56f..819d1b9 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 28, 2012"
+.TH PNG 5 "February 1, 2012"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 0381f79..5a14b3d 100644
--- a/png.c
+++ b/png.c
@@ -762,13 +762,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.6.0beta08 - January 31, 2012" PNG_STRING_NEWLINE \
+     "libpng version 1.6.0beta08 - February 1, 2012" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2012 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.6.0beta08 - January 31, 2012\
+      return "libpng version 1.6.0beta08 - February 1, 2012\
       Copyright (c) 1998-2012 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 57c1124..06d3e5d 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.6.0beta08 - January 28, 2012
+ * libpng version 1.6.0beta08 - February 1, 2012
  *
  * Copyright (c) 1998-2012 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 890a7d3..bc2160d 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1012,7 +1012,7 @@
          pngtest_debug1("Handling %d iTXt/tEXt/zTXt chunks", num_text);
 
          if (verbose)
-            printf("\nText compression=%d\n", text_ptr->compression);
+            printf("\n Text compression=%d\n", text_ptr->compression);
 
          png_set_text(write_ptr, write_info_ptr, text_ptr, num_text);
       }
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index f25331c..852ba3a 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.6.0beta08 - January 28, 2012
+libpng version 1.6.0beta08 - February 1, 2012
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 6f9e3f2..b727c76 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.6.0beta08 - January 28, 2012
+ * libpng version 1.6.0beta08 - February 1, 2012
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 43d2828..4007e1a 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.6.0beta08 - January 28, 2012
+Makefiles for  libpng version 1.6.0beta08 - February 1, 2012
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 3546b63..4b1e545 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng 1.6.0beta08 - January 28, 2012 */
+/* Libpng 1.6.0beta08 - February 1, 2012 */
 
 /* Copyright (c) 1998-2012 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index c5c02bf..d4b850f 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.6.0beta08 - January 31, 2012
  * Copyright (c) 1998-2012 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.6.0beta08 - January 31, 2012: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -198,7 +198,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, January 31, 2012, are
  * Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -310,7 +310,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 31, 2012
+ *    February 1, 2012
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -376,7 +376,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.6.0beta08"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.6.0beta08 - January 31, 2012\n"
+     " libpng version 1.6.0beta08 - February 1, 2012\n"
 
 #define PNG_LIBPNG_VER_SONUM   16
 #define PNG_LIBPNG_VER_DLLNUM  16
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.6.0beta08 - January 31, 2012
+ * libpng version 1.6.0beta08 - February 1, 2012
  * Copyright (c) 1998-2012 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.6.0beta08 - January 31, 2012: Glenn
+ *   libpng versions 0.97, January 1998, through 1.6.0beta08 - February 1, 2012: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -198,7 +198,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, January 31, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.0beta08, February 1, 2012, are
  * Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5